[−][src]Struct https_everywhere_lib_wasm::CookieRule
A CookieRule is used to secure cookies which conform to some name and host constraints
Fields
host_regex: Stringname_regex: StringMethods
impl CookieRule[src]
pub fn new(host_regex: String, name_regex: String) -> CookieRule[src]
Returns a cookierule with the host and scope regex specified
Arguments
host_regex- A string that will be compiled to regex indicating the host of the cookiename_regex- A string that will be compiled to regex indicating the name of the cookie